@@ -1,7 +1,8 @@
 #include "common.h"
+#include "fs.h"
 #include "dbaccess.h"
 
-int readdb(const char *iface, const char *dirname)
+int readdb(const char *iface, const char *dirname, const int force)
 {
 	FILE *db;
 	char file[512], backup[512];
@@ -37,6 +38,15 @@ int readdb(const char *iface, const char *dirname)
 		}
 	}
 
+	if (data.version == DBVERSION) {
+		if (!validatedb() && !force) {
+			data.version=-1;
+			if (debug) {
+				printf("db: Database for interface \"%s\" fails to validate, trying with backup\n", data.interface);
+			}
+		}
+	}
+
 	/* convert old database to new format if necessary */
 	if (data.version<DBVERSION) {
 		if (data.version!=-1) {
@@ -76,13 +86,22 @@ int readdb(const char *iface, const char *dirname)
 				}
 			} else {
 				if (debug) {
-					printf("db: Database loaded for interface \"%s\"...\n", data.interface);
+					printf("db: Backup database loaded for interface \"%s\"...\n", data.interface);
+				}
+			}
+
+			if (data.version == DBVERSION) {
+				if (!validatedb()) {
+					data.version=-1;
+					if (debug) {
+						printf("db: Backup database for interface \"%s\" fails to validate\n", data.interface);
+					}
 				}
 			}
 
 			if (data.version!=DBVERSION) {
-				if (!convertdb()) {
-					snprintf(errorstring, 512, "Unable to use backup database.");
+				if ((data.version==-1) || (!convertdb())) {
+					snprintf(errorstring, 512, "Unable to use database \"%s\" or backup database \"%s\".", file, backup);
 					printe(PT_Error);
 					fclose(db);
 
@@ -252,6 +271,7 @@ int writedb(const char *iface, const char *dirname, int newdb)
 		if ((newdb) && (noexit==0)) {
 			snprintf(errorstring, 512, "-> A new database has been created.");
 			printe(PT_Info);
+			matchdbownerwithdirowner(dirname);
 		}
 	}
 
@@ -528,7 +548,7 @@ void cleartop10(const char *iface, const char *dirname)
 {
 	int i;
 
-	if (readdb(iface, dirname)!=0) {
+	if (readdb(iface, dirname, 0)!=0) {
 		exit(EXIT_FAILURE);
 	}
 
@@ -546,7 +566,7 @@ void rebuilddbtotal(const char *iface, const char *dirname)
 {
 	int i;
 
-	if (readdb(iface, dirname)!=0) {
+	if (readdb(iface, dirname, 0)!=0) {
 		exit(EXIT_FAILURE);
 	}
 
@@ -567,23 +587,35 @@ int validatedb(void)
 	int i, used;
 	uint64_t rxsum, txsum;
 
+	if (debug) {
+		printf("validating loaded database\n");
+	}
+
+	/* enforce string termination */
+	data.interface[sizeof(data.interface)-1] = '\0';
+	data.nick[sizeof(data.nick)-1] = '\0';
+
 	if (data.version>DBVERSION) {
-		printf("Invalid database version: %d\n", data.version);
+		snprintf(errorstring, 512, "%s: Invalid database version: %d", data.interface, data.version);
+		printe(PT_Error);
 		return 0;
 	}
 
 	if (data.active<0 || data.active>1) {
-		printf("Invalid database activity status: %d\n", data.active);
+		snprintf(errorstring, 512, "%s: Invalid database activity status: %d", data.interface, data.active);
+		printe(PT_Error);
 		return 0;
 	}
 
 	if (!strlen(data.interface)) {
-		printf("Invalid database interface string: %s\n", data.interface);
+		snprintf(errorstring, 512, "Invalid database interface string: %s", data.interface);
+		printe(PT_Error);
 		return 0;
 	}
 
 	if (!data.created || !data.lastupdated || !data.btime) {
-		printf("Invalid database timestamp.\n");
+		snprintf(errorstring, 512, "%s: Invalid database timestamp.", data.interface);
+		printe(PT_Error);
 		return 0;
 	}
 
@@ -591,15 +623,18 @@ int validatedb(void)
 	used = 1;
 	for (i=0; i<30; i++) {
 		if (data.day[i].used<0 || data.day[i].used>1) {
-			printf("Invalid database daily use information: %d %d\n", i, data.day[i].used);
+			snprintf(errorstring, 512, "%s: Invalid database daily use information: %d %d", data.interface, i, data.day[i].used);
+			printe(PT_Error);
 			return 0;
 		}
 		if (data.day[i].rxk<0 || data.day[i].txk<0) {
-			printf("Invalid database daily traffic: %d\n", i);
+			snprintf(errorstring, 512, "%s: Invalid database daily traffic: %d", data.interface, i);
+			printe(PT_Error);
 			return 0;
 		}
 		if (data.day[i].used && !used) {
-			printf("Invalid database daily use order: %d\n", i);
+			snprintf(errorstring, 512, "%s: Invalid database daily use order: %d", data.interface, i);
+			printe(PT_Error);
 			return 0;
 		} else if (!data.day[i].used) {
 			used = 0;
@@ -615,13 +650,15 @@ int validatedb(void)
 			break;
 		}
 		if (data.day[i-1].date < data.day[i].date) {
-			printf("Invalid database daily date order: %u (%d) < %u (%d)\n", (unsigned int)data.day[i-1].date, i-1, (unsigned int)data.day[i].date, i);
+			snprintf(errorstring, 512, "%s: Invalid database daily date order: %u (%d) < %u (%d)", data.interface, (unsigned int)data.day[i-1].date, i-1, (unsigned int)data.day[i].date, i);
+			printe(PT_Error);
 			return 0;
 		}
 	}
 
 	if (data.totalrx < rxsum || data.totaltx < txsum) {
-		printf("Invalid database total traffic compared to daily usage.\n");
+		snprintf(errorstring, 512, "%s: Invalid database total traffic compared to daily usage.", data.interface);
+		printe(PT_Error);
 		return 0;
 	}
 
@@ -629,15 +666,18 @@ int validatedb(void)
 	used = 1;
 	for (i=0; i<12; i++) {
 		if (data.month[i].used<0 || data.month[i].used>1) {
-			printf("Invalid database monthly use information: %d %d\n", i, data.month[i].used);
+			snprintf(errorstring, 512, "%s: Invalid database monthly use information: %d %d", data.interface, i, data.month[i].used);
+			printe(PT_Error);
 			return 0;
 		}
 		if (data.month[i].rxk<0 || data.month[i].txk<0) {
-			printf("Invalid database monthly traffic: %d\n", i);
+			snprintf(errorstring, 512, "%s: Invalid database monthly traffic: %d", data.interface, i);
+			printe(PT_Error);
 			return 0;
 		}
 		if (data.month[i].used && !used) {
-			printf("Invalid database monthly use order: %d\n", i);
+			snprintf(errorstring, 512, "%s: Invalid database monthly use order: %d", data.interface, i);
+			printe(PT_Error);
 			return 0;
 		} else if (!data.month[i].used) {
 			used = 0;
@@ -653,28 +693,33 @@ int validatedb(void)
 			break;
 		}
 		if (data.month[i-1].month < data.month[i].month) {
-			printf("Invalid database monthly date order: %u (%d) < %u (%d)\n", (unsigned int)data.month[i-1].month, i-1, (unsigned int)data.month[i].month, i);
+			snprintf(errorstring, 512, "%s: Invalid database monthly date order: %u (%d) < %u (%d)", data.interface, (unsigned int)data.month[i-1].month, i-1, (unsigned int)data.month[i].month, i);
+			printe(PT_Error);
 			return 0;
 		}
 	}
 
 	if (data.totalrx < rxsum || data.totaltx < txsum) {
-		printf("Invalid database total traffic compared to monthly usage.\n");
+		snprintf(errorstring, 512, "%s: Invalid database total traffic compared to monthly usage.", data.interface);
+		printe(PT_Error);
 		return 0;
 	}
 
 	used = 1;
 	for (i=0; i<10; i++) {
 		if (data.top10[i].used<0 || data.top10[i].used>1) {
-			printf("Invalid database top10 use information: %d %d\n", i, data.top10[i].used);
+			snprintf(errorstring, 512, "%s: Invalid database top10 use information: %d %d", data.interface, i, data.top10[i].used);
+			printe(PT_Error);
 			return 0;
 		}
 		if (data.top10[i].rxk<0 || data.top10[i].txk<0) {
-			printf("Invalid database top10 traffic: %d\n", i);
+			snprintf(errorstring, 512, "%s: Invalid database top10 traffic: %d", data.interface, i);
+			printe(PT_Error);
 			return 0;
 		}
 		if (data.top10[i].used && !used) {
-			printf("Invalid database top10 use order: %d\n", i);
+			snprintf(errorstring, 512, "%s: Invalid database top10 use order: %d", data.interface, i);
+			printe(PT_Error);
 			return 0;
 		} else if (!data.top10[i].used) {
 			used = 0;
