@@ -876,10 +876,10 @@ void showhours(void)
 	}
 
 	/* unit selection */
-	while (max/(pow(1024, div))>=100 && div<UNITCOUNT) {
+	while (max/(pow(1024, div))>=100 && div<UNITPREFIXCOUNT) {
 		div++;
 	}
-	strncpy_nt(unit, getunit(div), 4);
+	strncpy_nt(unit, getunitprefix(div), 4);
 	div = pow(1024, div-1);
 	if (div == 1) {
 		declen = 0;
@@ -888,7 +888,7 @@ void showhours(void)
 	/* structure */
 	snprintf(matrix[11], 81, " -+--------------------------------------------------------------------------->");
 	for (i=0;i<3;i++) {
-		snprintf(matrix[14]+(i*28), 25, " h %2$*1$srx (%3$s)  %2$*1$stx (%3$s)", 1+cfg.unit, " ", unit);
+		snprintf(matrix[14]+(i*28), 25, " h %2$*1$srx (%3$s)  %2$*1$stx (%3$s)", 1+cfg.unitmode, " ", unit);
 	}
 
 	for (i=10;i>1;i--)
