@@ -10,9 +10,9 @@ vnStat - Copyright (c) 2002-2016 Teemu Toivola <tst@iki.fi>
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program;  if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave., Cambridge, MA 02139, USA.
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, write to the Free Software Foundation, Inc.,
+   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include "common.h"
@@ -584,8 +584,8 @@ void handleimport(PARAMS *p)
 		printf("Error: validation of imported database failed.\n");
 		exit(EXIT_FAILURE);
 	}
-	/* set boot time to zero in order to force counter sync */
-	data.btime = 0;
+	/* set boot time to one in order to force counter sync */
+	data.btime = 1;
 	strncpy_nt(data.interface, p->interface, 32);
 	if (writedb(p->interface, p->dirname, 1)) {
 		printf("Database import for \"%s\" completed.\n", data.interface);
